package com.mgh.pmdm.parques.repository

import android.content.Context
import android.util.Log
import androidx.lifecycle.LiveData
import com.mgh.pmdm.parques.R
import com.mgh.pmdm.parques.db.DatabaseBuilder
import com.mgh.pmdm.parques.db.Park
import kotlinx.coroutines.coroutineScope

class ParkRepository private constructor(
    // En el constructor primario se nos proporciona un
    // contexto, necesario para acceder a los recursos.
    private var context: Context
) {

    // Objeto complementario (estático) que contendrá la
    // instancia única de la clase, y el método getInstance,
    // para instanciar esta.
    companion object {
        private var INSTANCE: ParkRepository? = null
        fun getInstance(context: Context): ParkRepository {
            if (INSTANCE == null) {
                INSTANCE = ParkRepository(context)
            }
            return INSTANCE!!
        }
    }

    fun getParks(): LiveData<List<Park>> {
        return DatabaseBuilder.getInstance(context).parkDao().getAll()
    }

    suspend fun removePark(park: Park): Int =
        DatabaseBuilder.getInstance(context).parkDao().deletePark(park)

    suspend fun update(park: Park) = DatabaseBuilder.getInstance(context).parkDao().updatePark(park)

    suspend fun add(park: Park) = DatabaseBuilder.getInstance(context).parkDao().addPark(park)

}
